@@ -102,7 +102,7 @@ class ItemCategory(IntEnum):
     CROSSBOW = 24
     CAMO = 99
     INFANTRY = 100
-    VEHIVLES = 101
+    VEHICLES = 101
     INFANTRY_WEAPONS = 102
     INFANTRY_GEAR = 103
     VEHICLE_WEAPONS = 104
@@ -141,7 +141,7 @@ class ItemCategory(IntEnum):
     FEMALE_VO_PACK = 137
     VALKYRIE_NOSE_GUNNER = 138
     INFANTRY_ABILITIES = 139
-    VEHIVLE_ABILITIES = 140
+    VEHICLE_ABILITIES = 140
     BOOST_AND_UTILITIES = 141
     CONSOLIDATED_DECAL = 142
     ATTACHMENTS = 143
@@ -168,7 +168,7 @@ class PlayerState(IntEnum):
     CROUCHING = 1
     RUNNING = 2
     SPRINTING = 3
-    FALLINH_LONG = 4
+    FALLING_LONG = 4
     CROUCH_WALKING = 5
 
 
